# study-cli
command line flash cards

# Installation
> pip install study-cli

To get the git version, run:

> git clone git://github.com/fawzisal/study-cli.git

## Usage
TBD

## Bug reports
To report bugs, please use the chemicals's Bug Tracker at:
>    https://github.com/fawzisal/study-cli/issues

## License information
See ``LICENSE.txt`` for information on the terms & conditions for usage of this software, and a DISCLAIMER OF ALL WARRANTIES.
